"""Append all commands to Nuke's user interface."""

# Import third-party modules
import nuke
import nukescripts

# Import local modules
from smartRecents import helper
from smartRecents import thumbnail
from smartRecents import osl as smartrecents


def add_to_ui():
    """Build smartRecents menu and append commands to it."""
    menu = nuke.menu("Nuke").addMenu(
        "cragl/smartRecents",
        icon=helper.load_icons()["icon_logo"]
    )
    menu.addCommand(
        "open",
        lambda: smartrecents.show(True),
        "Alt+O"
    )
    menu.addSeparator()
    menu.addCommand(
        "set preview image from current node",
        thumbnail.set_preview_image, "Alt+Shift+P"
    )
    menu.addCommand(
        "take screenshot for current working file",
        thumbnail.take_screenshot
    )
    menu.addSeparator()
    menu.addCommand(
        "&settings",
        lambda: smartrecents.show(False)
    )
    menu.addSeparator()
    menu.addCommand(
        "&about",
        smartrecents.show_about_window
    )


def add_callbacks():
    """Add necessary callbacks for smartRecents."""
    # Add the current working file to the smartRecents history when saving.
    nuke.addOnScriptSave(helper.save_to_recent_xml)

    # Add dropData callback for inserting/ appending file to DAG.
    nukescripts.addDropDataCallback(smartrecents.insert_file)

    # Set onClose callbacks to take auto thumbnail on closing Nuke.
    thumbnail.set_auto_thumbnail_callback()


def check_show():
    """Check if we should show the smartRecents window on start up."""
    show_smr = helper.load_settings()["showSmartRecents"]
    if show_smr == "True":
        smartrecents.show(True)


add_to_ui()
add_callbacks()
check_show()
